%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% oup-contemporary.cls, v1.3, 2021/01/05
% Modified by Journal of Computational Design and Engineering
%
% oup-contemporary.cls, v1.2, 2020/12/09
% Modified by Journal of Computational Design and Engineering
%
% oup-contemporary.cls, v1.1, 2017/06/28
% Developed by Overleaf
% 
% This class file enables authors to prepare 
% manuscripts for submission to OUP journals using the
% 'contemporary' layout.
%
% V1.0 Supported journals:
% - general
%
% V1.1
% - Moved logos to top level (EM requirements)
% - Handles missing/empty logo files
%
% V1.2 Supported journals:
% - Journal of Computational Design and Engineering
% - The Bitter family of fonts with LATEX support 
%   OUP typesetting will use the Caecilia font family for final production
%
% V1.3
% - Changed the citation and reference style to American Psychological Association (APA), Seventh Edition
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
\ProvidesClass{oup-contemporary}[2021/01/05, v1.3]

\newif\if@numrefs
\newif\if@alpharefs

%% Options for bibliography style
\DeclareOption{num-refs}{
  \@numrefstrue
  \@alpharefsfalse
}
\DeclareOption{alpha-refs}{
  \@numrefsfalse
  \@alpharefstrue
}

\DeclareOption*{\PassOptionsToClass{\CurrentOption}{article}}

\ExecuteOptions{num-refs}
\ProcessOptions\relax
\LoadClass[twoside,twocolumn]{article}
\RequirePackage{algorithm}%
\RequirePackage{algorithmicx}%
\RequirePackage{algpseudocode}%
\RequirePackage[utf8]{inputenc}
\RequirePackage[T1]{fontenc}
\RequirePackage{ifpdf}
\RequirePackage{microtype}
\RequirePackage{euler}
\RequirePackage{bitter}
\renewcommand{\ttdefault}{lmtt}
\RequirePackage[italic]{mathastext}
\RequirePackage{relsize}
\RequirePackage{ragged2e}
\RequirePackage{xcolor}
\RequirePackage{colortbl}
\RequirePackage{graphicx}
\RequirePackage{etoolbox,xpatch}
\RequirePackage{environ}
\RequirePackage{lastpage}
\RequirePackage{rotating}
\RequirePackage{lscape}
\RequirePackage{afterpage}
\RequirePackage[absolute]{textpos}
\RequirePackage{url}
\RequirePackage{newfloat}
\RequirePackage{mdframed}
\RequirePackage{titlesec}
\RequirePackage{scrextend}
\changefontsizes[10.5pt]{7.5pt}
\RequirePackage{calc}
\RequirePackage[american]{babel}
\RequirePackage{csquotes}
\RequirePackage[style=apa,sortcites=true,sorting=nyt,backend=biber,hyperref=true]{biblatex}
%\RequirePackage[bibstyle=custom-numeric-comp,sortcites=true,sorting=nyt,backend=biber,hyperref=true]{biblatex}
\DeclareLanguageMapping{american}{american-apa}
\RequirePackage[colorlinks,allcolors=jurlc]{hyperref}
\addbibresource{bibliography.bib}

\RequirePackage{geometry}
\geometry{includefoot,%set page layout
 paperwidth = 210mm,
 paperheight = 276mm,
 left=55pt,
 right=57pt,
 bottom=3pc+9pt,
 headheight=15pt,
 top=20mm-1pt,
 marginpar=0pt,
 headsep=21pt-2mm,
 %footnotesep=1pc+6pt,
 columnsep=7mm-1pt,
 footskip = 12pt
}

\setlength{\parindent}{12pt}
\definecolor{jurlc}{RGB}{0, 154, 207} 
\RequirePackage[blocks]{authblk}

\def\@ouplogo{oup.pdf}

\def\@jname{Journal of X}
\def\@jlogo{example-grid-100x100pt.png}
\def\@jhomepage{www.jcde.org}

\newcommand{\jname}[1]{\def\@jname{#1}}
\newcommand{\jlogo}[1]{\def\@jlogo{#1}}

\def\@jyear{20xx}
\def\@jvolume{0}
\def\@jnumber{0}
\def\@jstartpage{5}
\def\@jendpage{0}
\def\@jpubdate{19 August 2020}

\newcommand{\jyear}[1]{\def\@jyear{#1}}
\newcommand{\jvolume}[1]{\def\@jvolume{#1}}
\newcommand{\jnumber}[1]{\def\@jnumber{#1}}
\newcommand{\jstartpage}[1]{\def\@jstartpage{#1}}
\newcommand{\jendpage}[1]{\def\@jendpage{#1}}
\newcommand{\jpubdate}[1]{\def\@jpubdate{#1}}


\def\@doi{10.1093/jcde/}
\def\@papercat{}
\def\@runningtitle{}
\def\@corraddress{}
\def\@authnotes{}
\def\@page{}
\colorlet{jcolour}{blue!40}

\newcommand{\doi}[1]{\def\@doi{#1}}
\newcommand{\runningtitle}[1]{\def\@runningtitle{#1}}
\newcommand{\corraddress}[1]{\def\@corraddress{#1}}
\newcommand{\authnote}[1]{\appto{\@authnotes}{#1\par}}
\newcommand{\papercat}[1]{\def\@papercat{#1}}

\newcommand{\jfooterreceived}[1]{\def \@jfooterreceived{#1}}
\newcommand{\jfooterreviesed}[1]{\def \@jfooterreviesed{#1}}
\newcommand{\jfooteraccepted}[1]{\def \@jfooteraccepted{#1}}


\newcommand{\journal}[1]{%
  \ifstrequal{#1}{jcde}{%
    \jname{Journal of Computational Design and Engineering}%
    \jlogo{cde.pdf}%
    \definecolor{jcolour}{RGB}{236,151,26}%
    \definecolor{jcolour_line}{RGB}{250,208,154}%
  }{}
  \ifstrequal{#1}{general}{%
    \jname{Journal of XYZ}%
    \jlogo{example-grid-100x100pt.png}%
    \definecolor{jcolour}{RGB}{128,0,0}%
    \definecolor{jcolour_line}{RGB}{128,0,0}%
  }
}

\RequirePackage[flushmargin,bottom,norule]{footmisc}
\appto{\footnotelayout}{\fontsize{6.5pt}{9.5pt}\selectfont}
\deffootnote{1.5em}{1.5em}{\thefootnotemark\enspace}


\RequirePackage{fancyhdr}
\fancyhf{}
\renewcommand{\headrule}{\color{black!15}\rule{\textwidth}{2pt} }
\fancyhead[LE]{%\
  \hspace*{11pt}%
  \fontsize{7.8pt}{10pt}\selectfont%
  \color{jcolour}%
  \textbf{\thepage}
  %\hspace{1em}\raisebox{-0.5pt}{|}\hspace{1em}%\
  \hspace{5pt}\raisebox{-0.5pt}{|}\hspace{5pt}%\
  \@runningtitle
%   \textit{\@jname}, \@jyear, Vol.~\@jvolume, No.~\@jnumber
\vspace{-5.5pt}
}
\fancyhead[RO]{%
  \fontsize{7.8pt}{10pt}\selectfont%
  \color{jcolour}%
  \@jname, \@jyear, \@jvolume(\@jnumber) \@jstartpage-\@jendpage%
  \hspace{5pt}\raisebox{-0.5pt}{|}\hspace{5pt}%
  \textbf{\thepage}%
  \hspace*{11pt}%
  \vspace{-5.5pt}
}

\fancypagestyle{plain}{%
  \fancyhf{}
  \renewcommand{\headrule}{}
  \fancyfoot[R]{%
    \fontsize{7.8pt}{10pt}\selectfont%
    \color{jcolour}%
    \textbf{\thepage}\hspace*{11pt}%
  }
}
\pagestyle{fancy}

\AtBeginDocument{%
\setlength{\bibhang}{3ex} 
  \newsavebox{\@jcdecitedetails}
  \newlength{\@jcdecitedetailsheight}
  \newsavebox{\@jcdeheadbox}
  \newlength{\@jcdeheadboxheight}
  \savebox{\@jcdecitedetails}{%
    %\parbox{\textwidth-21pc}{%+4pc+6.64pt}{%
    \parbox{295pt}{%+4pc+6.64pt}{%
%     \normalfont{\itshape\bfseries\@jname}, \@jyear, \@jstartpage--\pageref{LastPage}\par
%     \vspace{\dimexpr 8pt-1em\relax}
    {\color{black!15}\rule{\linewidth}{2pt}}\par%
    %\vspace{\dimexpr 8pt-1em\relax}%
    \vspace{\dimexpr 11pt-1em\relax}%
    \fontsize{6.5pt}{9.5pt}\selectfont%
    \textcolor{jcolour}{doi: \@doi}\par
    Journal homepage: {\url{\@jhomepage}}\par
    Advance Access Publication Date: \@jpubdate\par
    \vspace{\dimexpr 7pt-1em\relax}%
    {\color{black!15}\rule{\linewidth}{2pt}}\par
  }}%
  \settototalheight{\@jcdecitedetailsheight}{\usebox{\@jcdecitedetails}}%
  %%%%
  \savebox{\@jcdeheadbox}{%
  

    \parbox{\textwidth-21pc+4pc+6.64pt}{%
    \normalfont%
    \fontsize{8pt}{9.5pt}\selectfont%
    %{\itshape\bfseries\@jname}, \@jyear, \@jvolume(--\pageref{LastPage}\par
    {\itshape\@jname}, \@jyear, \@jvolume(\@jnumber), \@jstartpage-\@jendpage \par
    \vspace{\dimexpr 8pt-2.5pt\relax}%
    \usebox{\@jcdecitedetails}
    }%
  }%
  \settototalheight{\@jcdeheadboxheight}{\usebox{\@jcdeheadbox}}%
}

\RequirePackage{alphalph}
\newalphalph{\fnsymbolmult}[mult]{\@fnsymbol}{5}
\newcounter{authorfn}
\setcounter{authorfn}{1}
\newcommand{\authfn}[1]{%
  {\fnsymbolmult{#1}}%
}

\renewcommand\Authands{ and }
\renewcommand\AB@affilsepx{ and }
\renewcommand{\Authfont}{\fontsize{13pt}{18pt}\selectfont}
\renewcommand{\Affilfont}{\fontsize{9pt}{13pt}\selectfont}
%\setlength{\affilsep}{21pt-9pt}

\AtBeginDocument{
\renewcommand{\@maketitle}{%
  %\textblockorigin{4pc+6.64pt}{4pc}
  \textblockorigin{4pc+9pt}{4pc-3pt}
  %%%%
  \begin{textblock*}{20pc}(0pt,0pt)
  %\textblockcolour{red}
  
  \IfFileExists{\@ouplogo}{%
    \includegraphics[height=0.83\@jcdeheadboxheight]{\@ouplogo}%
  }{%
    \fbox{\begin{minipage}[b][\@jcdeheadboxheight]{\@jcdeheadboxheight}
    \raggedright
    Placeholder for OUP logo \@ouplogo
    \end{minipage}}%
  }
  \hspace{8pt}%
  %% Do absolutely nothing if \@jlogo is empty string
  \ifdefempty{\@jlogo}{}{%
  \IfFileExists{\@jlogo}{%
    \includegraphics[height=0.83\@jcdeheadboxheight]{\@jlogo}
  }{%
    \fbox{\begin{minipage}[b][\@jcdeheadboxheight]{\@jcdeheadboxheight}%
    \raggedright Placeholder for journal logo \@jlogo
    \end{minipage}}%
  }}
  \end{textblock*}
  %%%
  %\begin{textblock*}{\textwidth-25pc}(19pc,0pt)
  \begin{textblock*}{\textwidth-27pc}(19pc-3pt,0pt)
  \usebox{\@jcdeheadbox}
  \end{textblock*}%
  %%%
  %\null\vspace*{\dimexpr 13pc-5pc-10pt\relax}%
  \null\vspace*{\dimexpr 9pc-4pt\relax}%
  \raggedright%
  {\fontsize{11pt}{13pt}\selectfont%
    \ifpdf
      \textls[200]{\MakeUppercase{\@papercat}}
    \else %%% don't use letterspace in latex+dvi
      \MakeUppercase{\@papercat}%
    \fi%
    \par}
  %\vspace{\dimexpr 26pt-18pt\relax}
  {\fontsize{18pt}{27pt}\bfseries\color{jcolour}\@title\par}
  %\vspace{\dimexpr 26pt-13pt\relax}
  \vspace{\dimexpr 26pt-18pt\relax}
  \@author\par
  %\vspace{\dimexpr 15.5pt-1em}
  \vspace{\dimexpr 15.5pt-1em}
  {%
    \renewcommand{\authfn}[1]{
      \textsuperscript{\fnsymbolmult{##1}}%
    }
    {\fontsize{6.5pt}{9.5pt}\selectfont\@authnotes\par}%
  }
  %\vspace{\dimexpr 16pt-3pt-1em\relax}
  \vspace{\dimexpr 16pt-2pt-1em\relax}
}
}

\RequirePackage[style]{abstract}
\setlength{\absleftindent}{0pt}
\setlength{\absrightindent}{0pt}
\setlength{\absparindent}{12pt}
\setlength{\absparsep}{0pt}
\setlength{\abstitleskip}{16pt-8pt-\baselineskip}
\renewcommand{\abstractnamefont}{\fontsize{10pt}{12pt}\bfseries\color{jcolour}}
\renewcommand{\abstitlestyle}[1]{{\abstractnamefont #1}}
\renewcommand{\abstracttextfont}{\fontsize{8pt}{11pt}\selectfont}
\preto{\abstract}{%
  %{\noindent\color{jcolour!40}\rule{\hsize+4pc+6.64pt}{3pt}}\par
  {\noindent\color{jcolour_line}\rule{\hsize+4pc+6.64pt}{3pt}}\par
  %\vspace*{\dimexpr 23pt-10pt\relax}
  \vspace*{\dimexpr 23pt-20pt\relax}
}
\appto\abstract{\noindent\raggedright\ignorespaces}
\preto\endabstract{\par}

\newenvironment{keywords}
{\vspace*{\dimexpr 19pt-8pt-\baselineskip\relax}%
\noindent\fontsize{8pt}{11pt}\selectfont\textit{Keywords}: \ignorespaces}%
{\par}

\DeclareFloatingEnvironment[placement=t!,name=kpt]{keypoints}

\xapptocmd{\keypoints*}{%
  \begin{mdframed}[linewidth=1pt,linecolor=black,
  innerleftmargin=8pt,innerrightmargin=8pt,
  innertopmargin=16pt-8.2pt,innerbottommargin=6pt]
  {\fontsize{8.2pt}{10pt}\bfseries Key Points\par}
}{}{}
\xpretocmd{\endkeypoints*}{\end{mdframed}}{}{}


\if@twocolumn
  \NewEnviron{frontmatter}[3]
  {\twocolumn[%
      \BODY%
      \vspace*{\dimexpr 16pt-4pt-1em\relax}
      {\noindent\color{jcolour_line}\rule{\hsize+4pc+6.64pt}{3pt}}\par
      \vspace*{\dimexpr 23pt-1em\relax}
      ]%
      
    \begin{figure*}[b!]
      \fontsize{6.5pt}{9.5pt}\selectfont%
      \hrule%
      %\vspace{\dimexpr 14pt-6.5pt\relax}%
      \vspace{\dimexpr 12pt-3.5pt\relax}%
      \textbf{Received: } #1; \textbf{Revised: } #2; \textbf{Accepted: } #3
      \vspace{\dimexpr 2pt\relax}%
      \newline
      \copyright \, The Author(s) 2020. Published by Oxford University Press on behalf of the Society for Computational Design and Engineering. This is an Open Access article distributed under the terms of the Creative Commons Attribution Non-Commercial License (\url{http://creativecommons.org/licenses/by-nc/4.0/}), which permits non-commercial re-use, distribution, and reproduction in any medium, provided the original work is properly cited. For commercial re-use, please contact \href{mailto:journals.permissions@oup.com}{journals.permissions@oup.com}
      \par
    \end{figure*}
  }
\else
  \NewEnviron{frontmatter}[3]{%
      \BODY%
      \vspace*{\dimexpr 16pt-3pt-1em\relax}
      {\noindent\color{jcolour_line}\rule{\hsize+4pc+6.64pt}{3pt}}\par
      \vspace*{\dimexpr 23pt-1em\relax}%
    \begin{figure*}[b!]
      \fontsize{6.5pt}{9.5pt}\selectfont%
      \hrule%
      \vspace{\dimexpr 14pt-6.5pt\relax}%
      \textbf{Compiled on:} \today.\par
      Draft manuscript prepared by the author.\par
    \end{figure*}
  }
\fi

\titleformat{\section}[hang]{\fontsize{10pt}{12pt} \bfseries \color{jcolour}}{\thesection. }{0pt}{}
%\titlespacing*{\section}{0pt}{25.5pt-1em}{1em}
\titlespacing*{\section}{0pt}{25pt-1em}{1em-1ex-1pt}

\titleformat*{\subsection}{\fontsize{8.5pt}{11pt}\bfseries\color{jcolour}}
%\titlespacing*{\subsection}{0pt}{2pc-1em}{17pt-1em}
\titlespacing*{\subsection}{0pt}{2pc-1em}{1em-1ex-1pt}
\titleformat*{\subsubsection}{\normalsize\bfseries\slshape}
\titlespacing*{\subsubsection}{0pt}{\baselineskip}{0pt}
\titleformat{\paragraph}[runin]{\normalsize\itshape}{\theparagraph}{0pt}{}[.\enspace]
\titlespacing*{\paragraph}{0pt}{\baselineskip}{0pt}
  \titleformat{\subparagraph}[runin]{\relsize{-1}\uppercase}{\thesubparagraph}{0pt}{}[.\enspace]
\titlespacing*{\subparagraph}{0pt}{\baselineskip}{0pt}
\titleformat{\part}[hang]{\fontsize{10pt}{12pt} \bfseries \color{jcolour}}{}{0pt}{}
\titlespacing*{\part}{0pt}{26.5pt-1em}{3pt}

\RequirePackage{enumitem}
\setlist{noitemsep}
\setlist[itemize]{leftmargin=12pt,topsep=16pt-1em}
\setlist[enumerate]{leftmargin=12pt, topsep=16pt-1em, label={(\roman*)}}
% Changes to the list parameters for enumerate

% quotes and epigraphs
\RequirePackage{quoting}
\newcommand{\quotefont}{\fontsize{6.5pt}{9.5pt}\selectfont}
\quotingsetup{vskip=16pt-1em,indentfirst=false,font={quotefont},leftmargin=12pt,rightmargin=12pt}

\renewenvironment{quote}{\begin{quoting}}{\end{quoting}}

\renewenvironment{quotation}{\begin{quoting}}{\end{quoting}}

\newenvironment{epigraph}[1]
{\begin{quoting}[font={itshape,fontsize{7.5pt}{10.5pt}},vskip=15pt-1em,leftmargin=0pt,rightmargin=0pt]%
 \def\@quotesource{#1}}
{\par\vspace{\dimexpr 15pt-1em\relax}{\upshape---\@quotesource}\end{quoting}}

% Space above/below equations
\g@addto@macro\normalsize{%
  \setlength\abovedisplayskip{\baselineskip}%
  \setlength\belowdisplayskip{\baselineskip}%
  \setlength\abovedisplayshortskip{\baselineskip}%
  \setlength\belowdisplayshortskip{\baselineskip}%
}

\RequirePackage{stfloats}
\RequirePackage{booktabs}
\RequirePackage{tabularx}
% Left-, right- and center-aligned auto-wrapping column types
\newcolumntype{L}{>{\raggedright\arraybackslash}X}
\newcolumntype{R}{>{\raggedleft\arraybackslash}X}
\newcolumntype{C}{>{\centering\arraybackslash}X}

\AtBeginEnvironment{tabularx}{%
  \fontsize{7pt}{10pt}\selectfont
}
\AtBeginEnvironment{tabular}{%
  \fontsize{7pt}{10pt}\selectfont
}

\setlength{\aboverulesep}{11pt-1em}
\setlength{\belowrulesep}{11pt-1em}
\setlength{\heavyrulewidth}{0.5pt}
\setlength{\lightrulewidth}{0.5pt}
\arrayrulecolor{jcolour}


\newcommand{\tnote}[1]{\textsuperscript{\textit{#1}}}
\newlist{tablenotes}{itemize}{1}
\setlist[tablenotes]{label={},labelsep=0pt,leftmargin=0pt,topsep={\dimexpr 12pt-1em\relax}}
\appto{\tablenotes}{\fontsize{6pt}{9pt}\selectfont}

\RequirePackage[tableposition=top]{caption}
\DeclareCaptionTextFormat{hnamei}{hcode using #1i}
\DeclareCaptionFont{figcaptionfont}{\fontsize{6pt}{9pt}\selectfont}
\DeclareCaptionFont{tabcaptionfont}{\fontsize{7pt}{9pt}\selectfont}
\captionsetup{justification=justified,singlelinecheck=false,labelfont={bf},labelsep=colon}
\captionsetup*[figure]{font=figcaptionfont,skip=10pt}
\captionsetup*[table]{font=tabcaptionfont,skip=10pt-1em}

% Skips for floats
\setlength{\floatsep}{1pc+6pt}
\setlength{\intextsep}{1pc+6pt}
\setlength{\textfloatsep}{1pc+6pt}

% References
%\bibliographystyle{apa-test}